pub struct Collection {
pub id: String,
pub title: Option<String>,
pub description: Option<String>,
pub keywords: Vec<String>,
pub attribution: Option<String>,
pub extent: Option<Extent>,
pub item_type: Option<String>,
pub crs: Vec<Crs>,
pub storage_crs: Option<Crs>,
pub storage_crs_coordinate_epoch: Option<f32>,
pub links: Links,
pub additional_properties: Map<String, Value>,
}Expand description
A body of resources that belong or are used together. An aggregate, set, or group of related resources.
Fields
id: Stringtitle: Option<String>description: Option<String>keywords: Vec<String>attribution: Option<String>Attribution for the collection.
extent: Option<Extent>item_type: Option<String>An indicator about the type of the items in the collection.
crs: Vec<Crs>The list of coordinate reference systems supported by the API; the first item is the default coordinate reference system.
storage_crs: Option<Crs>storage_crs_coordinate_epoch: Option<f32>links: Linksadditional_properties: Map<String, Value>Trait Implementations
Sourceimpl Clone for Collection
impl Clone for Collection
Sourcefn clone(&self) -> Collection
fn clone(&self) -> Collection
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Collection
impl Debug for Collection
Sourceimpl Default for Collection
impl Default for Collection
Sourceimpl<'de> Deserialize<'de> for Collection
impl<'de> Deserialize<'de> for Collection
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for Collection
impl PartialEq for Collection
Sourceimpl Serialize for Collection
impl Serialize for Collection
impl StructuralPartialEq for Collection