Conformance

Struct Conformance 

pub struct Conformance {
    pub conforms_to: Vec<String>,
}
The Conformance declaration states the conformance classes from standards or community specifications, identified by a URI, that the API conforms to. Clients can but are not required to use this information. Accessing the Conformance declaration using HTTP GET returns the list of URIs of conformance classes implemented by the server.

Fields

conforms_to: Vec<String>

Implementations

Source

impl Conformance

pub fn new(classes: &[impl ToString]) -> Self

pub fn extend(&mut self, classes: &[impl ToString])

Extend conformance from other classes