pub struct Exception {
pub type: String,
pub title: Option<String>,
pub status: Option<u16>,
pub detail: Option<String>,
pub instance: Option<String>,
pub additional_properties: Map<String, Value>,
}Expand description
Exception based on RFC 7807
Fields
type: StringA URI reference that identifies the problem type.
title: Option<String>A short, human-readable summary of the problem type.
status: Option<u16>The HTTP status code generated by the origin server for this occurrence of the problem.
detail: Option<String>A human-readable explanation specific to this occurrence of the problem.
instance: Option<String>A URI reference that identifies the specific occurrence of the problem. It may or may not yield further information if dereferenced.
additional_properties: Map<String, Value>Implementations
Sourceimpl Exception
impl Exception
pub fn new(type: impl ToString) -> Self
pub fn new_from_status(status: u16) -> Self
pub fn title(self, title: impl ToString) -> Self
pub fn status(self, status: u16) -> Self
pub fn detail(self, detail: impl ToString) -> Self
pub fn instance(self, instance: impl ToString) -> Self